@@ -33,6 +33,8 @@
 #include <cstring>
 #include <ctime>
 #include <iostream>
+#include <mutex>
+#include <signal.h>
 #include <string>
 #include <thread>
 
@@ -69,7 +71,6 @@
 #    include <cstdio>
 #    include <io.h>
 #    include <malloc.h>
-#    include <windows.h>
 #else
 #    include <sys/resource.h>
 #endif
@@ -83,6 +84,12 @@
 #include <OpenImageIO/strutil.h>
 #include <OpenImageIO/sysutil.h>
 
+#include <boost/version.hpp>
+#if BOOST_VERSION >= 106500
+#    define _GNU_SOURCE
+#    include <boost/stacktrace.hpp>
+#endif
+
 // clang 7.0 (rc2) has errors when including boost thread!
 // The only thin we're using there is boost::physical_concurrency.
 #if !(OIIO_CLANG_VERSION >= 7)
@@ -583,6 +590,8 @@ Sysutil::max_open_files()
     return size_t(-1);  // Couldn't figure out, so return effectively infinity
 }
 
+
+
 void*
 aligned_malloc(std::size_t size, std::size_t align)
 {
@@ -594,6 +603,8 @@ aligned_malloc(std::size_t size, std::size_t align)
 #endif
 }
 
+
+
 void
 aligned_free(void* ptr)
 {
@@ -605,4 +616,60 @@ aligned_free(void* ptr)
 }
 
 
+
+std::string
+Sysutil::stacktrace()
+{
+#if BOOST_VERSION >= 106500
+    std::stringstream out;
+    out << boost::stacktrace::stacktrace();
+    return out.str();
+#else
+    return "";
+#endif
+}
+
+
+
+#if BOOST_VERSION >= 106500
+
+static std::string stacktrace_filename;
+static std::mutex stacktrace_filename_mutex;
+
+static void
+stacktrace_signal_handler(int signum)
+{
+    ::signal(signum, SIG_DFL);
+    if (!stacktrace_filename.empty()) {
+        if (stacktrace_filename == "stdout")
+            std::cout << Sysutil::stacktrace();
+        else if (stacktrace_filename == "stderr")
+            std::cerr << Sysutil::stacktrace();
+        else {
+#    if BOOST_VERSION >= 106500
+            boost::stacktrace::safe_dump_to(stacktrace_filename.c_str());
+#    endif
+        }
+    }
+    ::raise(SIGABRT);
+}
+
+#endif
+
+
+
+bool
+Sysutil::setup_crash_stacktrace(string_view filename)
+{
+#if BOOST_VERSION >= 106500
+    std::lock_guard<std::mutex> lock(stacktrace_filename_mutex);
+    stacktrace_filename = filename;
+    ::signal(SIGSEGV, &stacktrace_signal_handler);
+    ::signal(SIGABRT, &stacktrace_signal_handler);
+    return true;
+#endif
+    return false;
+}
+
+
 OIIO_NAMESPACE_END
