@@ -85,6 +85,7 @@ void declare_imageoutput (py::module& m);
 void declare_typedesc (py::module& m);
 void declare_roi (py::module& m);
 void declare_deepdata (py::module& m);
+void declare_colorconfig (py::module& m);
 void declare_imagecache (py::module& m);
 void declare_imagebuf (py::module& m);
 void declare_imagebufalgo (py::module& m);
@@ -130,9 +131,12 @@ py_indexable_pod_to_stdvector(std::vector<T>& vals, const PYT& obj)
         } else if ((std::is_same<T, float>::value || std::is_same<T, int>::value)
                    && py::isinstance<py::int_>(elem)) {
             vals.emplace_back(elem.template cast<int>());
+        } else if (std::is_same<T, unsigned int>::value
+                   && py::isinstance<py::int_>(elem)) {
+            vals.emplace_back(elem.template cast<unsigned int>());
         } else {
             // FIXME? Other cases?
-            vals.emplace_back(T(0));
+            vals.emplace_back(T(42));
             ok = false;
         }
     }
@@ -329,6 +333,13 @@ attribute_typed(T& myobj, string_view name, TypeDesc type, const POBJ& dataobj)
             myobj.attribute(name, type, &vals[0]);
         return;
     }
+    if (type.basetype == TypeDesc::UINT) {
+        std::vector<unsigned int> vals;
+        py_to_stdvector(vals, dataobj);
+        if (vals.size() == type.numelements() * type.aggregate)
+            myobj.attribute(name, type, &vals[0]);
+        return;
+    }
     if (type.basetype == TypeDesc::FLOAT) {
         std::vector<float> vals;
         py_to_stdvector(vals, dataobj);
@@ -390,6 +401,7 @@ struct oiio_bufinfo {
     void* data       = nullptr;
     stride_t xstride = AutoStride, ystride = AutoStride, zstride = AutoStride;
     size_t size = 0;
+    std::string error;
 
     oiio_bufinfo(const py::buffer_info& pybuf, int nchans, int width,
                  int height, int depth, int pixeldims);
